use axum::extract::Request;
use axum::http::{HeaderName, HeaderValue};
use axum::middleware::Next;
use axum::response::Response;
use ulid::Ulid;

/// 请求ID中间件
pub async fn handle(mut request: Request, next: Next) -> Response {
    let req_id = HeaderValue::from_str(&Ulid::new().to_string()).unwrap_or_else(|err| {
        tracing::error!("error is {}", err);
        HeaderValue::from_static("unknown")
    });

    request
        .headers_mut()
        .insert(HeaderName::from_static("x-request-id"), req_id.to_owned());

    let mut response = next.run(request).await;

    response
        .headers_mut()
        .insert(HeaderName::from_static("x-request-id"), req_id);

    response
}
